@@ -66,7 +66,7 @@ while test $# -gt 0; do
 		echo_exec_prefix=true
 		;;
 	--version)
-		echo VERSION=9.11.9
+		echo VERSION=9.11.11
 		exit 0
 		;;
 	--cflags)
@@ -157,7 +157,7 @@ if test x"$echo_libs" = x"true"; then
 		needothers=true
 	fi
 	if test x"$needothers" = x"true" ; then
-		libs="$libs  -pthread -ljson-c -lpthread -lm -lGeoIP  -L/usr/local/lib -Wl,-rpath=/usr/local/lib -L/usr/local/lib -lxml2 -lz -L/usr/local/lib -llzma -lpthread -L/usr/local/lib -liconv -lm -L/usr/local/lib"
+		libs="$libs  -pthread -ljson-c -lpthread  -L/usr/local/lib -lxml2 -lz -L/usr/local/lib -llzma -lpthread -L/usr/local/lib -liconv -lm -L/usr/local/lib "
 	fi
 	echo $libs
 fi
